/* 
 * (c) Copyright Darwino Inc. 2014-2017.
 */
import React, { Component } from "react";
import PropTypes from 'prop-types';
import { Modal, Button, Form, FormGroup, FormControl, ControlLabel } from 'react-bootstrap';
import { BaseDialog } from '@darwino/darwino-react'


/*
 * Common dialog component.
 */

class Dialog extends BaseDialog {

    renderHeader() {
        const {title} = this.state;
        return (
            <Modal.Header closeButton>
                {title && <Modal.Title>{title}</Modal.Title>}
            </Modal.Header>
        )
    }

    renderBody() {
        const {body} = this.state;
        return (
            <Modal.Body>
                {body &&
                    typeof body==='function' 
                        ? body(this)
                        : body
                }
            </Modal.Body>
        )
    }

    promptDialog(dialog) {
        const {label,placeHolder} = this.props
        return (
            <FormGroup>
                {label && <ControlLabel>{label}</ControlLabel>}
                <FormControl type="text" placeHolder={placeHolder} autoFocus
                    value={dialog.state.value}
                    onChange={(e) => dialog.setState({value:e.target.value})}/>
            </FormGroup>
        )    
    }
        
    renderFooter() {
        const {actions} = this.state;
        const _this = this
        return (actions.length &&
            <Modal.Footer>
                {actions.map((a,idx) => { return (
                    <Button key={idx} bsStyle={a.btStyle || "primary"} type={a.type} onClick={() => a.action(_this)}>
                        {a.title}
                    </Button>
                )}) }
            </Modal.Footer>
        )
    }

    render() {
        const {show} = this.state;
        return (show && 
            <Modal show={true} onHide={() => this.close(Dialog.CANCEL)} 
                    aria-labelledby='contained-modal-title'>
                <Form>
                    {this.renderHeader()}
                    {this.renderBody()}
                    {this.renderFooter()}
                </Form>
            </Modal>
        )
    }
}

export default Dialog;