/* 
 * (c) Copyright Darwino Inc. 2014-2017.
 */
import React, { Component } from "react";
import { Link } from "react-router-dom";
import { BaseCursorList } from '@darwino/darwino-react';

/*
 * Expected properties:
 * - databaseId (string)
 * - storeId (string)
 * - params (object)
 * - columns (array of objects (title/key))
 * - baseRoute (string)
 * 
 * Note: 'store' is a reserved prop with redux so the parameter is 'storeId', and 'databaseId' for consistency.
 */
class TableCursorList extends BaseCursorList {

    constructor(props) {
        super(props);
        this.getViewEntryCells = this.getViewEntryCells.bind(this);
    }

    getViewEntries() {
        const { columns } = this.props;
        const { dataFetcher } = this;
        if(dataFetcher.isFetching()) {
            return (<tr><td colSpan={columns.length}>Fetching...</td></tr>);
        } if(dataFetcher.isError()) {
            return (<tr><td colSpan={columns.length}><pre>Error: {dataFetcher.getErrorMessage()||"Unknown - please look at the log"}</pre></td></tr>);
        } else {
            if(dataFetcher.getRowCount()==0) {
                return (<tr><td colSpan={columns.length}>No entries found</td></tr>)
            } else {
                return dataFetcher.getRows(0, dataFetcher.getRowCount()).map((entry, index) =>
                    <tr key={entry.unid} onClick={() => this.handleRowClick(entry)}>
                        {this.getViewEntryCells(entry)}
                    </tr>)
            }
        }
    }
    getViewEntryCells(entry) {
        const { columns } = this.props;
        return columns.map(col =>
            <td key={entry.__meta.unid+col.key}>{entry[col.key]}</td>
        );
    }

    getAddRowsButton() {
        const { addRowsButtonText } = this.props;
        if(!addRowsButtonText) {
            return null
        } else {
            return (
                <button style={this.dataFetcher.hasMoreRows() ? {} : {display: 'none'}} onClick={this.loadMoreRows}>{addRowsButtonText}</button>
            )
        }
    }

    
    render() {
        const { viewEntries, columns } = this.props;
        
        return (
            <div>
                <div className="table-responsive">
                    <table className="table table-striped table-condensed table-bordered table-hover darwino-view">
                        <thead>
                            <tr>
                                {columns.map(col => <th key={col.key}>{col.title}</th>)}
                            </tr>
                        </thead>
                        <tbody>
                            {this.getViewEntries()}
                        </tbody>
                    </table>
                    {this.getAddRowsButton()}
                </div>
            </div>
        );
  }
}

export default TableCursorList
